@@ -99,14 +99,12 @@ class ItemsManager(Manager, AllMixin, GetByIdMixin, SyncMixin):
         }
         self.queue.append(cmd)
 
-    def uncomplete(self, project_id, item_ids, update_item_orders=1,
-                   restore_state=None):
+    def uncomplete(self, item_ids, update_item_orders=1, restore_state=None):
         """
         Marks items as not completed remotely, by appending the equivalent request to the
         queue.
         """
         args = {
-            'project_id': project_id,
             'ids': item_ids,
             'update_item_orders': update_item_orders,
         }
@@ -141,21 +139,6 @@ class ItemsManager(Manager, AllMixin, GetByIdMixin, SyncMixin):
         }
         self.queue.append(cmd)
 
-    def uncomplete_update_meta(self, project_id, ids_to_metas):
-        """
-        Marks an item as completed remotely, by appending the equivalent
-        request to the queue.
-        """
-        cmd = {
-            'type': 'item_uncomplete_update_meta',
-            'uuid': self.api.generate_uuid(),
-            'args': {
-                'project_id': project_id,
-                'ids_to_metas': ids_to_metas,
-            },
-        }
-        self.queue.append(cmd)
-
     def update_orders_indents(self, ids_to_orders_indents):
         """
         Updates the order and indents of multiple items remotely, by appending
